import { Ref } from "vue";
import { LocationQuery, LocationQueryValue } from "vue-router";
import { PaginatedListRequest } from '../model/PaginatedList';
export declare class ScrollListKey {
    private params?;
    private forceUpdate;
    constructor(params?: Ref<any>[] | undefined);
    setParams(params: Ref[]): void;
    forceRefresh(): void;
    key(): string;
}
export type QueryConverter<T> = {
    toQueryString?: (value: T) => string;
    fromQueryString?: (query: LocationQueryValue | LocationQueryValue[]) => T | undefined;
};
export type ScrollListFilterItem = {
    name: string;
    value: Ref;
    defaultValue?: unknown;
    queryConverter?: QueryConverter<unknown>;
};
export declare class ScrollListFilter {
    private params?;
    private queryRef;
    constructor(params?: ScrollListFilterItem[] | undefined);
    setParams(params: ScrollListFilterItem[]): void;
    createUrlQuery(locationQuery: LocationQuery): LocationQuery;
    static isQueryEqual(query1: LocationQuery, query2: LocationQuery): boolean;
    private createRequestQuery;
    private extractNonFilterQuery;
    syncUrlQuery(locationQuery: LocationQuery): void;
    private convertToQuery;
    private convertFromQuery;
    createListKey(): ScrollListKey;
    getParamValues(): Record<string, Ref>;
}
export declare const numberQueryConverter: QueryConverter<unknown>;
export declare class AbstractScrollListFilter {
    limit: number;
    page?: number;
    forceRefreshKey: number;
    constructor(limit?: number);
    setLimit(limit?: number): void;
    setPage(page?: number): void;
    /**
     * 필터가 변경되지 않아도 강제로 업데이트 되도록, forceRefreshKey 를 변경한다.
     */
    forceRefresh(): void;
    getOffset(): number;
    getPaginatedListRequest(): PaginatedListRequest;
}
export declare class EmptyScrollListFilter extends AbstractScrollListFilter {
    constructor(limit: number);
    /**
     * filter 항목으로부터 LocationQuery 를 생성한다.
     * 결과 query 에는 `originalQuery` 에 있는 filter 가 아닌 항목도 포함된다.
     * @param originalQuery
     */
    createQuery(originalQuery?: LocationQuery): LocationQuery;
    /**
     * query 내용을 filter 에 적용한다.
     * @param query
     */
    syncQuery(query: LocationQuery): void;
    /**
     * UiScrollList 의 listKey 에 사용할 string 을 리턴한다.
     */
    getListKey(): string;
}
