import dayjs from "dayjs"
import durationPlugin from "dayjs/plugin/duration"

dayjs.extend(durationPlugin)

/**
 * millisecond 단위의 시간을 '3일 04:20:34' 형식의 시간 문자열로 만든다.
 * 시간이 1일 보다 작은 경우, '일' 부분은 제외된다.
 * @param timeMillis millisecond 단위의 시간
 * @param hmsFormat 시/분/초 형식
 * @param dayFormat 일 형식
 */
export const formatDuration = (timeMillis?: number, dayFormat = 'DD ', hmsFormat = 'HH:mm:ss'): string => {
  if (!timeMillis || (timeMillis < 0)) return ''

  // days 가 1 이상인 경우에만 dayFormat 을 적용한다.
  const days = Math.floor(timeMillis / 24 / 60 / 60 / 1000)
  const dd = (days >= 1) ? dayFormat.replace('DD', days.toFixed()) : ''

  // hour, minute, second format
  const hms = dayjs.duration(timeMillis).format(hmsFormat)

  return `${dd}${hms}`
}